@@ -47,7 +47,7 @@ def ifcfg_config_path(name):
 
 
 def remove_ifcfg_config(ifname):
-    if re.match('[\w-]+$', ifname):
+    if re.match(r'[\w-]+$', ifname):
         ifcfg_file = ifcfg_config_path(ifname)
         if os.path.exists(ifcfg_file):
             os.remove(ifcfg_file)
@@ -430,7 +430,7 @@ class IfcfgNetConfig(os_net_config.NetConfig):
             data += "PKEY=yes\n"
             data += "PHYSDEV=%s\n" % base_opt.parent
             data += "PKEY_ID=%s\n" % base_opt.pkey_id
-        elif re.match('\w+\.\d+$', base_opt.name):
+        elif re.match(r'\w+\.\d+$', base_opt.name):
             data += "VLAN=yes\n"
         elif isinstance(base_opt, objects.Interface):
             if base_opt.linkdelay:
@@ -464,7 +464,7 @@ class IfcfgNetConfig(os_net_config.NetConfig):
         if isinstance(base_opt, objects.OvsBridge):
             data += "DEVICETYPE=ovs\n"
             data += "TYPE=OVSBridge\n"
-            if base_opt.use_dhcp:
+            if base_opt.use_dhcp or base_opt.use_dhcpv6:
                 data += "OVSBOOTPROTO=dhcp\n"
             if base_opt.members:
                 members = [member.name for member in base_opt.members]
@@ -481,7 +481,7 @@ class IfcfgNetConfig(os_net_config.NetConfig):
         elif isinstance(base_opt, objects.OvsUserBridge):
             data += "DEVICETYPE=ovs\n"
             data += "TYPE=OVSUserBridge\n"
-            if base_opt.use_dhcp:
+            if base_opt.use_dhcp or base_opt.use_dhcpv6:
                 data += "OVSBOOTPROTO=dhcp\n"
             if base_opt.members:
                 members = [member.name for member in base_opt.members]
@@ -497,7 +497,7 @@ class IfcfgNetConfig(os_net_config.NetConfig):
                 self.bond_primary_ifaces[base_opt.name] = primary_name
             data += "DEVICETYPE=ovs\n"
             data += "TYPE=OVSBond\n"
-            if base_opt.use_dhcp:
+            if base_opt.use_dhcp or base_opt.use_dhcpv6:
                 data += "OVSBOOTPROTO=dhcp\n"
             if base_opt.members:
                 members = [member.name for member in base_opt.members]
@@ -1114,6 +1114,18 @@ class IfcfgNetConfig(os_net_config.NetConfig):
             self._add_rules(contrail_vrouter_dpdk.name,
                             contrail_vrouter_dpdk.rules)
 
+    def add_linux_tap(self, linux_tap):
+        """Add a LinuxTap object to the net config object
+
+        :param linux_tap:
+           The LinuxTap object to add
+        """
+        logger.info('adding Linux TAP interface: %s'
+                    % linux_tap.name)
+        data = self._add_common(linux_tap)
+        data += "TYPE=Tap\n"
+        self.interface_data[linux_tap.name] = data
+
     def generate_ivs_config(self, ivs_uplinks, ivs_interfaces):
         """Generate configuration content for ivs."""
 
@@ -1228,6 +1240,7 @@ class IfcfgNetConfig(os_net_config.NetConfig):
         restart_ib_childs = []
         restart_bridges = []
         restart_linux_bonds = []
+        start_linux_bonds = []
         restart_linux_teams = []
         restart_vpp = False
         apply_interfaces = []
@@ -1236,6 +1249,7 @@ class IfcfgNetConfig(os_net_config.NetConfig):
         apply_rules = []
         update_files = {}
         all_file_names = []
+        linux_bond_children = {}
         ivs_uplinks = []  # ivs physical uplinks
         ivs_interfaces = []  # ivs internal ports
         nfvswitch_interfaces = []       # nfvswitch physical interfaces
@@ -1491,11 +1505,12 @@ class IfcfgNetConfig(os_net_config.NetConfig):
             all_file_names.append(bond_route_path)
             all_file_names.append(bond_route6_path)
             all_file_names.append(bond_rule_path)
+            children = self.child_members(bond_name)
+            linux_bond_children[bond_name] = children
             if utils.diff(bond_path, bond_data):
                 if self.ifcfg_requires_restart(bond_path, bond_data):
                     restart_linux_bonds.append(bond_name)
                     # Avoid duplicate interface being added to the restart list
-                    children = self.child_members(bond_name)
                     for child in children:
                         if child not in restart_interfaces:
                             restart_interfaces.append(child)
@@ -1750,6 +1765,10 @@ class IfcfgNetConfig(os_net_config.NetConfig):
 
             for interface in restart_interfaces:
                 self.ifdown(interface)
+                for bond in linux_bond_children:
+                    if interface in linux_bond_children[bond]:
+                        if bond not in restart_linux_bonds:
+                            start_linux_bonds.append(bond)
 
             for linux_bond in restart_linux_bonds:
                 self.ifdown(linux_bond)
@@ -1820,6 +1839,10 @@ class IfcfgNetConfig(os_net_config.NetConfig):
             for interface in restart_interfaces:
                 self.ifup(interface)
 
+            for linux_bond in start_linux_bonds:
+                if linux_bond not in restart_linux_bonds:
+                    restart_linux_bonds.append(linux_bond)
+
             for linux_bond in restart_linux_bonds:
                 self.ifup(linux_bond)
 
